@@ -12,7 +12,7 @@
 /***************************************************************/
 
 #include "config.h"
-static char const RCSID[] = "$Id: init.c,v 1.6 1998/02/14 03:56:33 dfs Exp $";
+static char const RCSID[] = "$Id: init.c,v 1.8 1998/03/02 19:38:40 dfs Exp $";
 
 #define L_IN_INIT 1
 #include <stdio.h>
@@ -123,6 +123,7 @@ char *argv[];
     /* Initialize global dynamic buffers */
     DBufInit(&Banner);
     DBufInit(&LineBuffer);
+    DBufInit(&ExprBuf);
 
     DBufPuts(&Banner, L_BANNER);
 
@@ -257,9 +258,16 @@ char *argv[];
 	    case 'z':
 	    case 'Z':
 		DontFork = 1;
-		PARSENUM(Daemon, arg);
-		if (Daemon<5) Daemon=5;
-		else if (Daemon>60) Daemon=60;
+		if (*arg == '0') {
+		    PARSENUM(Daemon, arg);
+		    if (Daemon == 0) Daemon = -1;
+		    else if (Daemon < 5) Daemon = 5;
+		    else if (Daemon > 60) Daemon = 60;
+		} else {
+		    PARSENUM(Daemon, arg);
+		    if (Daemon<5) Daemon=5;
+		    else if (Daemon>60) Daemon=60;
+		}
 		break;
 
 	    case 'a':
